summaryrefslogtreecommitdiffstats
path: root/Bugzilla
diff options
context:
space:
mode:
authorCharlie Somerville <charlie@charliesomerville.com>2014-02-27 09:48:50 +0100
committerFrédéric Buclin <LpSolit@gmail.com>2014-02-27 09:48:50 +0100
commitd0308956b71eac546865487bf50c328456471b27 (patch)
treea33825be09176ca0a20cdb6fc669eb5d70a0b18c /Bugzilla
parent684499b0d3c75cb498af82e6df4da84c10658e32 (diff)
downloadbugzilla-d0308956b71eac546865487bf50c328456471b27.tar.gz
bugzilla-d0308956b71eac546865487bf50c328456471b27.tar.xz
Bug 947823: Replace gender-specific pronouns with gender-neutral pronouns
r=gerv a=justdave
Diffstat (limited to 'Bugzilla')
-rw-r--r--Bugzilla/Attachment.pm2
-rw-r--r--Bugzilla/Auth.pm4
-rw-r--r--Bugzilla/Auth/Verify/LDAP.pm2
-rw-r--r--Bugzilla/Bug.pm20
-rw-r--r--Bugzilla/Constants.pm10
-rw-r--r--Bugzilla/Flag.pm2
-rw-r--r--Bugzilla/Hook.pm2
-rw-r--r--Bugzilla/Install/DB.pm4
-rw-r--r--Bugzilla/Migrate.pm2
-rw-r--r--Bugzilla/Product.pm6
-rw-r--r--Bugzilla/Search.pm2
-rw-r--r--Bugzilla/Search/Quicksearch.pm2
-rw-r--r--Bugzilla/Token.pm16
-rw-r--r--Bugzilla/User.pm16
-rw-r--r--Bugzilla/Util.pm2
-rw-r--r--Bugzilla/WebService/Bug.pm4
-rw-r--r--Bugzilla/WebService/User.pm6
17 files changed, 51 insertions, 51 deletions
diff --git a/Bugzilla/Attachment.pm b/Bugzilla/Attachment.pm
index 0f3db8896..c90d8ea8e 100644
--- a/Bugzilla/Attachment.pm
+++ b/Bugzilla/Attachment.pm
@@ -729,7 +729,7 @@ sub validate_can_edit {
Description: validates if attachments the user wants to mark as obsolete
really belong to the given bug and are not already obsolete.
Moreover, a user cannot mark an attachment as obsolete if
- he cannot view it (due to restrictions on it).
+ they cannot view it (due to restrictions on it).
Params: $bug - The bug object obsolete attachments should belong to.
$attach_ids - The list of attachments to mark as obsolete.
diff --git a/Bugzilla/Auth.pm b/Bugzilla/Auth.pm
index 4e766cf0b..6b291d8ae 100644
--- a/Bugzilla/Auth.pm
+++ b/Bugzilla/Auth.pm
@@ -53,7 +53,7 @@ sub login {
return $self->_handle_login_result($login_info, $type);
}
- # Now verify his username and password against the DB, LDAP, etc.
+ # Now verify their username and password against the DB, LDAP, etc.
if ($self->{_info_getter}->{successful}->requires_verification) {
$login_info = $self->{_verifier}->check_credentials($login_info);
if ($login_info->{failure}) {
@@ -297,7 +297,7 @@ An incorrect username or password was given.
The hashref may also contain a C<failure_count> element, which specifies
how many times the account has failed to log in within the lockout
period (see L</AUTH_LOCKOUT>). This is used to warn the user when
-he is getting close to being locked out.
+they are getting close to being locked out.
=head2 C<AUTH_NO_SUCH_USER>
diff --git a/Bugzilla/Auth/Verify/LDAP.pm b/Bugzilla/Auth/Verify/LDAP.pm
index 63e05ed45..c113124f1 100644
--- a/Bugzilla/Auth/Verify/LDAP.pm
+++ b/Bugzilla/Auth/Verify/LDAP.pm
@@ -152,7 +152,7 @@ sub _bind_ldap_for_search {
# We can't just do this in new(), because we're not allowed to throw any
# error from anywhere under Bugzilla::Auth::new -- otherwise we
# could create a situation where the admin couldn't get to editparams
-# to fix his mistake. (Because Bugzilla->login always calls
+# to fix their mistake. (Because Bugzilla->login always calls
# Bugzilla::Auth->new, and almost every page calls Bugzilla->login.)
sub ldap {
my ($self) = @_;
diff --git a/Bugzilla/Bug.pm b/Bugzilla/Bug.pm
index a6347cb2e..f05533d25 100644
--- a/Bugzilla/Bug.pm
+++ b/Bugzilla/Bug.pm
@@ -1619,9 +1619,9 @@ sub _check_dup_id {
}
# Should we add the reporter to the CC list of the new bug?
- # If he can see the bug...
+ # If they can see the bug...
if ($self->reporter->can_see_bug($dupe_of)) {
- # We only add him if he's not the reporter of the other bug.
+ # We only add them if they're not the reporter of the other bug.
$self->{_add_dup_cc} = 1
if $dupe_of_bug->reporter->id != $self->reporter->id;
}
@@ -1636,11 +1636,11 @@ sub _check_dup_id {
$self->{_add_dup_cc} = $add_confirmed;
}
else {
- # Note that here we don't check if he user is already the reporter
- # of the dupe_of bug, since we already checked if he can *see*
+ # Note that here we don't check if the user is already the reporter
+ # of the dupe_of bug, since we already checked if they can *see*
# the bug, above. People might have reporter_accessible turned
# off, but cclist_accessible turned on, so they might want to
- # add the reporter even though he's already the reporter of the
+ # add the reporter even though they're already the reporter of the
# dup_of bug.
my $vars = {};
my $template = Bugzilla->template;
@@ -1783,7 +1783,7 @@ sub _check_reporter {
}
else {
# On bug creation, the reporter is the logged in user
- # (meaning that he must be logged in first!).
+ # (meaning that they must be logged in first!).
Bugzilla->login(LOGIN_REQUIRED);
$reporter = Bugzilla->user->id;
}
@@ -3181,7 +3181,7 @@ sub _resolve_ultimate_dup_id {
# If $dupes{$this_dup} is already set to 1, then a loop
# already exists which does not involve this bug.
# As the user is not responsible for this loop, do not
- # prevent him from marking this bug as a duplicate.
+ # prevent them from marking this bug as a duplicate.
return $last_dup if exists $dupes{$this_dup};
$dupes{$this_dup} = 1;
$last_dup = $this_dup;
@@ -4141,7 +4141,7 @@ sub check_can_change_field {
return 1;
}
- # If the user isn't allowed to change a field, we must tell him who can.
+ # If the user isn't allowed to change a field, we must tell them who can.
# We store the required permission set into the $PrivilegesRequired
# variable which gets passed to the error template.
#
@@ -4193,7 +4193,7 @@ sub check_can_change_field {
# is not allowed to change.
# The reporter may not:
- # - reassign bugs, unless the bugs are assigned to him;
+ # - reassign bugs, unless the bugs are assigned to them;
# in that case we will have already returned 1 above
# when checking for the assignee of the bug.
if ($field eq 'assigned_to') {
@@ -4210,7 +4210,7 @@ sub check_can_change_field {
$$PrivilegesRequired = PRIVILEGES_REQUIRED_ASSIGNEE;
return 0;
}
- # - change the priority (unless he could have set it originally)
+ # - change the priority (unless they could have set it originally)
if ($field eq 'priority'
&& !Bugzilla->params->{'letsubmitterchoosepriority'})
{
diff --git a/Bugzilla/Constants.pm b/Bugzilla/Constants.pm
index a296e2e25..a7f3f9e3b 100644
--- a/Bugzilla/Constants.pm
+++ b/Bugzilla/Constants.pm
@@ -432,8 +432,8 @@ use constant MAX_LOGIN_ATTEMPTS => 5;
# account is locked.
use constant LOGIN_LOCKOUT_INTERVAL => 30;
-# The time in minutes a user must wait before he can request another email to
-# create a new account or change his password.
+# The time in minutes a user must wait before they can request another email to
+# create a new account or change their password.
use constant ACCOUNT_CHANGE_INTERVAL => 10;
# The maximum number of seconds the Strict-Transport-Security header
@@ -590,10 +590,10 @@ use constant MAX_WEBDOT_BUGS => 2000;
# This is the name of the algorithm used to hash passwords before storing
# them in the database. This can be any string that is valid to pass to
# Perl's "Digest" module. Note that if you change this, it won't take
-# effect until a user logs in or changes his password.
+# effect until a user logs in or changes their password.
use constant PASSWORD_DIGEST_ALGORITHM => 'SHA-256';
# How long of a salt should we use? Note that if you change this, it
-# won't take effect until a user logs in or changes his password.
+# won't take effect until a user logs in or changes their password.
use constant PASSWORD_SALT_LENGTH => 8;
# Certain scripts redirect to GET even if the form was submitted originally
@@ -602,7 +602,7 @@ use constant PASSWORD_SALT_LENGTH => 8;
# See http://support.microsoft.com/kb/208427 for why MSIE is different
use constant CGI_URI_LIMIT => ($ENV{'HTTP_USER_AGENT'} || '') =~ /MSIE/ ? 2083 : 8000;
-# If the user isn't allowed to change a field, we must tell him who can.
+# If the user isn't allowed to change a field, we must tell them who can.
# We store the required permission set into the $PrivilegesRequired
# variable which gets passed to the error template.
diff --git a/Bugzilla/Flag.pm b/Bugzilla/Flag.pm
index f365afd98..177857ada 100644
--- a/Bugzilla/Flag.pm
+++ b/Bugzilla/Flag.pm
@@ -669,7 +669,7 @@ sub _check_requestee {
# Make sure the user didn't specify a requestee unless the flag
# is specifically requestable. For existing flags, if the requestee
# was set before the flag became specifically unrequestable, the
- # user can either remove him or leave him alone.
+ # user can either remove them or leave them alone.
ThrowUserError('flag_type_requestee_disabled', { type => $self->type })
if !$self->type->is_requesteeble;
diff --git a/Bugzilla/Hook.pm b/Bugzilla/Hook.pm
index 811e858d7..5e4114398 100644
--- a/Bugzilla/Hook.pm
+++ b/Bugzilla/Hook.pm
@@ -587,7 +587,7 @@ about, and the value should always be C<1>. The "relationships"
are described by the various C<REL_> constants in L<Bugzilla::Constants>.
Here's an example of adding userid C<123> to the recipient list
-as though he were on the CC list:
+as though they were on the CC list:
$recipients->{123}->{+REL_CC} = 1
diff --git a/Bugzilla/Install/DB.pm b/Bugzilla/Install/DB.pm
index a463fe879..d9bc494e0 100644
--- a/Bugzilla/Install/DB.pm
+++ b/Bugzilla/Install/DB.pm
@@ -871,8 +871,8 @@ sub _populate_longdescs {
if (!$who) {
# This username doesn't exist. Maybe someone
- # renamed him or something. Invent a new profile
- # entry disabled, just to represent him.
+ # renamed them or something. Invent a new profile
+ # entry disabled, just to represent them.
$dbh->do("INSERT INTO profiles (login_name,
cryptpassword, disabledtext)
VALUES (?,?,?)", undef, $name, '*',
diff --git a/Bugzilla/Migrate.pm b/Bugzilla/Migrate.pm
index db5db4712..2763ecb2b 100644
--- a/Bugzilla/Migrate.pm
+++ b/Bugzilla/Migrate.pm
@@ -756,7 +756,7 @@ sub insert_bugs {
# File the bug as the reporter.
my $super_user = Bugzilla->user;
my $reporter = Bugzilla::User->check($bug->{reporter});
- # Allow the user to file a bug in any product, no matter his current
+ # Allow the user to file a bug in any product, no matter their current
# permissions.
$reporter->{groups} = $super_user->groups;
Bugzilla->set_user($reporter);
diff --git a/Bugzilla/Product.pm b/Bugzilla/Product.pm
index e2c01151a..c3c3416b9 100644
--- a/Bugzilla/Product.pm
+++ b/Bugzilla/Product.pm
@@ -273,8 +273,8 @@ sub remove_from_db {
if (Bugzilla->params->{'allowbugdeletion'}) {
require Bugzilla::Bug;
foreach my $bug_id (@{$self->bug_ids}) {
- # Note that we allow the user to delete bugs he can't see,
- # which is okay, because he's deleting the whole Product.
+ # Note that we allow the user to delete bugs they can't see,
+ # which is okay, because they're deleting the whole Product.
my $bug = new Bugzilla::Bug($bug_id);
$bug->remove_from_db();
}
@@ -1025,7 +1025,7 @@ a group is valid in a particular product.)
Params: C<$user> - A Bugzilla::User object.
- Returns C<1> If this user's groups allow him C<entry> access to
+ Returns C<1> If this user's groups allow them C<entry> access to
this Product, C<0> otherwise.
=item C<flag_types()>
diff --git a/Bugzilla/Search.pm b/Bugzilla/Search.pm
index 23c632996..43de32774 100644
--- a/Bugzilla/Search.pm
+++ b/Bugzilla/Search.pm
@@ -3376,7 +3376,7 @@ value for this field. At least one search criteria must be defined if the
=item C<sharer>
-When a saved search is shared by a user, this is his user ID.
+When a saved search is shared by a user, this is their user ID.
=item C<user>
diff --git a/Bugzilla/Search/Quicksearch.pm b/Bugzilla/Search/Quicksearch.pm
index 5d3e16fe9..1a8823488 100644
--- a/Bugzilla/Search/Quicksearch.pm
+++ b/Bugzilla/Search/Quicksearch.pm
@@ -467,7 +467,7 @@ sub _handle_flags {
# are unable to run queries of the form (a AND b) OR c. In our case:
# (flag name is foo AND requestee is bar) OR (any other criteria).
# But this has never been possible, so this is not a regression. If one
- # needs to run such queries, he must use the Custom Search section of
+ # needs to run such queries, they must use the Custom Search section of
# the Advanced Search page.
$chart++;
$and = $or = 0;
diff --git a/Bugzilla/Util.pm b/Bugzilla/Util.pm
index 4b84b8ce4..5f359c38c 100644
--- a/Bugzilla/Util.pm
+++ b/Bugzilla/Util.pm
@@ -1131,7 +1131,7 @@ template. Just pass in the name of the variable that you want the value of.
Takes a time and converts it to the desired format and timezone.
If no format is given, the routine guesses the correct one and returns
an empty array if it cannot. If no timezone is given, the user's timezone
-is used, as defined in his preferences.
+is used, as defined in their preferences.
This routine is mainly called from templates to filter dates, see
"FILTER time" in L<Bugzilla::Template>.
diff --git a/Bugzilla/WebService/Bug.pm b/Bugzilla/WebService/Bug.pm
index b5ca96261..bb0ea1740 100644
--- a/Bugzilla/WebService/Bug.pm
+++ b/Bugzilla/WebService/Bug.pm
@@ -2479,7 +2479,7 @@ C<boolean> True if this bug is open, false if it is closed.
=item C<is_creator_accessible>
C<boolean> If true, this bug can be accessed by the creator (reporter)
-of the bug, even if he or she is not a member of the groups the bug
+of the bug, even if they are not a member of the groups the bug
is restricted to.
=item C<keywords>
@@ -4117,7 +4117,7 @@ C<string> The full login name of the bug's QA Contact.
=item C<is_creator_accessible>
C<boolean> Whether or not the bug's reporter is allowed to access
-the bug, even if he or she isn't in a group that can normally access
+the bug, even if they aren't in a group that can normally access
the bug.
=item C<remaining_time>
diff --git a/Bugzilla/WebService/User.pm b/Bugzilla/WebService/User.pm
index f3012ebc5..399d56113 100644
--- a/Bugzilla/WebService/User.pm
+++ b/Bugzilla/WebService/User.pm
@@ -193,7 +193,7 @@ sub get {
my $obj_by_ids;
$obj_by_ids = Bugzilla::User->new_from_list($params->{ids}) if $params->{ids};
- # obj_by_ids are only visible to the user if he can see
+ # obj_by_ids are only visible to the user if they can see
# the otheruser, for non visible otheruser throw an error
foreach my $obj (@$obj_by_ids) {
if (Bugzilla->user->can_see_user($obj)){
@@ -501,7 +501,7 @@ specified with the error.
=item 305 (New Password Required)
The current password is correct, but the user is asked to change
-his password.
+their password.
=item 50 (Param Required)
@@ -939,7 +939,7 @@ disabled/closed.
=item groups
C<array> An array of group hashes the user is a member of. If the currently
-logged in user is querying his own account or is a member of the 'editusers'
+logged in user is querying their own account or is a member of the 'editusers'
group, the array will contain all the groups that the user is a
member of. Otherwise, the array will only contain groups that the logged in
user can bless. Each hash describes the group and contains the following items:
diff --git a/Bugzilla/Token.pm b/Bugzilla/Token.pm
index 74f780542..535263868 100644
--- a/Bugzilla/Token.pm
+++ b/Bugzilla/Token.pm
@@ -39,7 +39,7 @@ sub issue_new_user_account_token {
my $vars = {};
# Is there already a pending request for this login name? If yes, do not throw
# an error because the user may have lost his email with the token inside.
# But to prevent using this way to mailbomb an email address, make sure
# the last request is old enough before sending a new email (default: 10 minutes).
@@ -66,7 +66,7 @@ sub issue_new_user_account_token {
# In 99% of cases, the user getting the confirmation email is the same one
# who made the request, and so it is reasonable to send the email in the same
# language used to view the "Create a New Account" page (we cannot use his
# user prefs as the user has no account yet!).
MessageToMTA($message);
}
@@ -133,7 +133,7 @@ sub IssuePasswordToken {
$vars->{'ip_addr'} = $ip_addr;
$vars->{'emailaddress'} = $user->email;
$vars->{'expiration_ts'} = ctime($token_ts + MAX_TOKEN_AGE * 86400);
- # The user is not logged in (else he wouldn't request a new password).
+ # The user is not logged in (else they wouldn't request a new password).
# So we have to pass this information to the template.
$vars->{'timezone'} = $user->timezone;
@@ -374,7 +374,7 @@ sub check_token_data {
{
# Something is going wrong. Ask confirmation before processing.
# It is possible that someone tried to trick an administrator.
# In this case, we want to know his name!
require Bugzilla::User;
my $vars = {};
@@ -471,7 +471,7 @@ Bugzilla::Token - Provides different routines to manage tokens.
Description: Creates and sends a token per email to the email address
requesting a new user account. It doesn't check whether
the user account already exists. The user will have to
- use this token to confirm the creation of his user account.
+ use this token to confirm the creation of their user account.
Params: $login_name - The new login name requested by the user.
@@ -494,7 +494,7 @@ Bugzilla::Token - Provides different routines to manage tokens.
Description: Sends a token per email to the given user. This token
can be used to change the password (e.g. in case the user
- cannot remember his password and wishes to enter a new one).
+ cannot remember their password and wishes to enter a new one).
Params: $user - User object of the user requesting a new password.
@@ -524,7 +524,7 @@ Bugzilla::Token - Provides different routines to manage tokens.
Description: Invalidates an existing token, generally when the token is used
for an action which is not the one expected. An email is sent
- to the user who originally requested this token to inform him
+ to the user who originally requested this token to inform them
that this token has been invalidated (e.g. because an hacker
tried to use this token for some malicious action).
@@ -537,7 +537,7 @@ Bugzilla::Token - Provides different routines to manage tokens.
=item C<DeletePasswordTokens($user_id, $reason)>
Description: Cancels all password tokens for the given user. Emails are sent
- to the user to inform him about this action.
+ to the user to inform them about this action.
Params: $user_id: The user ID of the user account whose password tokens
are canceled.
@@ -39,7 +39,7 @@ sub issue_new_user_account_token {
my $vars = {};
# Is there already a pending request for this login name? If yes, do not throw
- # an error because the user may have lost his email with the token inside.
+ # an error because the user may have lost their email with the token inside.
# But to prevent using this way to mailbomb an email address, make sure
# the last request is old enough before sending a new email (default: 10 minutes).
@@ -66,7 +66,7 @@ sub issue_new_user_account_token {
# In 99% of cases, the user getting the confirmation email is the same one
# who made the request, and so it is reasonable to send the email in the same
- # language used to view the "Create a New Account" page (we cannot use his
+ # language used to view the "Create a New Account" page (we cannot use their
# user prefs as the user has no account yet!).
MessageToMTA($message);
@@ -374,7 +374,7 @@ sub check_token_data {
# Something is going wrong. Ask confirmation before processing.
# It is possible that someone tried to trick an administrator.
- # In this case, we want to know his name!
+ # In this case, we want to know their name!
require Bugzilla::User;
my $vars = {};
diff --git a/Bugzilla/User.pm b/Bugzilla/User.pm
index e93d27ce8..4f047ebdd 100644
--- a/Bugzilla/User.pm
+++ b/Bugzilla/User.pm
@@ -321,7 +321,7 @@ sub authorizer {
}
# Generate a string to identify the user by name + login if the user
# has a name or by login only if she doesn't.
sub identity {
my $self = shift;
@@ -1252,7 +1252,7 @@ sub check_can_admin_flagtype {
my $e = $flagtype->exclusions_as_hash;
# If there is at least one product for which the user doesn't have
- # editcomponents privs, then don't allow him to do everything with
+ # editcomponents privs, then don't allow them to do everything with
# this flagtype, independently of whether this product is in the
# exclusion list or not.
my %product_ids;
@@ -2438,7 +2438,7 @@ Returns the 'real' name for this user, if any.
=item C<showmybugslink>
-Returns C<1> if the user has set his preference to show the 'My Bugs' link in
+Returns C<1> if the user has set their preference to show the 'My Bugs' link in
the page footer, and C<0> otherwise.
=item C<identity>
@@ -2542,7 +2542,7 @@ that you need to be able to see a group in order to bless it.
=item C<get_products_by_permission($group)>
Returns a list of product objects for which the user has $group privileges
-and which he can access.
+and which they can access.
$group must be one of the groups defined in PER_PRODUCT_PRIVILEGES.
=item C<can_see_user(user)>
@@ -2660,7 +2660,7 @@ not be aware of the existence of the product.
Description: Checks whether the user is allowed to edit properties of the flag type.
If the flag type is also used by some products for which the user
hasn't editcomponents privs, then the user is only allowed to edit
- the inclusion and exclusion lists for products he can administrate.
+ the inclusion and exclusion lists for products they can administrate.
Params: $flagtype_id - a flag type ID.
@@ -2769,7 +2769,7 @@ Params: login_name - B<Required> The login name for the new user.
a plain-text password. If you specify '*', the user will not
be able to log in using DB authentication.
disabledtext - The disable-text for the new user. If given, the user
- will be disabled, meaning he cannot log in. Defaults to an
+ will be disabled, meaning they cannot log in. Defaults to an
empty string.
disable_mail - If 1, bug-related mail will not be sent to this user;
if 0, mail will be sent depending on the user's email preferences.
@@ -2799,8 +2799,8 @@ Params: $username (scalar, string) - The full login name of the username
that you are checking.
$old_username (scalar, string) - If you are checking an email-change
token, insert the "old" username that the user is changing from,
- here. Then, as long as it's the right user for that token, he
- can change his username to $username. (That is, this function
+ here. Then, as long as it's the right user for that token, they
+ can change their username to $username. (That is, this function
will return a boolean true value).
=item C<login_to_id($login, $throw_error)>
@@ -321,7 +321,7 @@ sub authorizer {
}
# Generate a string to identify the user by name + login if the user
-# has a name or by login only if she doesn't.
+# has a name or by login only if they don't.
sub identity {
my $self = shift;